@@ -29,7 +29,7 @@ class SNR:
 
         self._df = df
 
-    def SNRspectra(self, s2=None, N=None):
+    def SNRmatrixspectra(self, s2=None, true=False):
 
         if s2 is None:
             s2 = self.s2[0]
@@ -39,14 +39,45 @@ class SNR:
         chi2inv = _chi2.ppf(1 - self.alpha, df)
 
         SNR = []
-        for S_n in self.Sigma:
-            SNR.append(S_n / _np.sqrt(chi2inv * s2))
+        if true:
+            ESigma = _np.linalg.svd(self.E, compute_uv=False)
+            for S_n in self.Sigma:
+                SNR.append(S_n / _np.max(ESigma))
+        else:
+            for S_n in self.Sigma:
+                SNR.append(S_n / _np.sqrt(chi2inv * s2))
 
         SNR = _np.array(SNR)
 
         return SNR
 
-    def scale2SNR_s2(self, SNR, n=None):
+    def SNRvectorspectra(self, S2=None, true=False):
+
+        SNR = []
+        if true:
+            for i in self.X:
+                SNR.append(_np.linalg.norm(self.X[i]) / _np.linalg.norm(self.E[i]))
+
+        else:
+            if S2 is None:
+                if hasattr(self, "CVE"):
+                    S2 = _np.diag(self.CVE)
+                else:
+                    raise ValueError("A vector 'S2' of variances must be supplied.")
+
+            df = self._df
+            df = df // self.X.shape[1]
+            chi2inv = _chi2.ppf(1 - self.alpha, df)
+
+            for i, x in enumerate(self.X):
+                SNR.append(_np.linalg.norm(self.X[x]) / _np.sqrt(chi2inv * S2[i]))
+
+        SNR = _np.array(SNR)
+
+        return SNR
+
+    def scaleVariance2SNR(self, SNR, n=None):
+        """Scale the variance to match a wished SNR"""
 
         if n is None:
             n = min(self.X.shape)
@@ -59,9 +90,3 @@ class SNR:
         s2 = S_n**2 / (chi2inv * SNR**2)
 
         return s2
-
-    def SNRspectra_phi(self):
-
-        SNR = []
-        for i in self.X:
-            SNR.append(_np.linalg.norm(self.X[i]) / _np.linalg.norm(self.E[i]))
